@@ -1,7 +1,7 @@
 import io
 import os
-import sys
 import shutil
+import sys
 
 from . import template
 
@@ -34,29 +34,17 @@ class save(template.SaveTemplate):
     def __LoadGoogle(self):
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
-        Tpath = None
-        Cpath = None
-        Opath = self.data.get("SettingsSave")
-        path = Opath
+        path = self.data.get("SettingsSave")
+        Tpath = path + "/gToken.json"
+        Cpath = path + "/gCred.json"
 
-        while Cpath is None:
-            path = os.path.dirname(path)
-            Tpath = path + "/gToken.json"
-            Cpath = path + "/gCred.json"
-
-            if not os.path.exists(Cpath):
-                Cpath = None
-                path = input(
-                    "Please enter location of files (Leave blank for run directory): ")
-                if path in ("", None):
-                    path = "."
-
-            shutil.copy(path + "/gCred.json", Opath + "/gCred.json")
-
-            # sys.exit(f"Please make sure the file: {Cpath} exists!")
+        if not os.path.exists(Cpath):
+            raise AttributeError(
+                "Failed to find `gCred.json` Please run save().DriveCredntials() first (and follow instructions in docs)")
 
         try:
             creds = None
@@ -102,7 +90,8 @@ class save(template.SaveTemplate):
         """
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         query = "trashed = false and 'me' in owners"
@@ -149,7 +138,8 @@ class save(template.SaveTemplate):
         """
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         items = self.__ListDirectory(folder, name)
@@ -160,7 +150,8 @@ class save(template.SaveTemplate):
     def WriteData(self, data: any, path: str, Encoding: bool = False) -> bool:
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         pathInfo = os.path.split(path)
@@ -197,7 +188,8 @@ class save(template.SaveTemplate):
     def ReadData(self, path: str, Encoding: bool = False) -> any:
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         pathInfo = os.path.split(path)
@@ -224,7 +216,8 @@ class save(template.SaveTemplate):
     def MakeFolders(self, path: str):
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         fileId = None
@@ -266,7 +259,8 @@ class save(template.SaveTemplate):
     def DeleteFolder(self, path: str):
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         return self.__DeleteByPath(path)
@@ -274,7 +268,8 @@ class save(template.SaveTemplate):
     def DeleteFile(self, path: str):
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         return self.__DeleteByPath(path)
@@ -289,7 +284,8 @@ class save(template.SaveTemplate):
     def __DeleteByID(self, fileId):
         if disabled:
             print(
-                "Missing google drive api. Install using `pip install PythonFunctions[google]`")
+                "Missing google drive api. Install using `pip install PythonFunctions[google]`"
+            )
             return False
 
         try:
